nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Mctl

Struct Mctl 

#[repr(transparent)]
pub struct Mctl(pub u32);
Miscellaneous Control Register

Tuple Fields

0: u32

Implementations

Source

impl Mctl

pub const fn samp_mode(&self) -> SampMode

Sample Mode

pub const fn set_samp_mode(&mut self, val: SampMode)

Sample Mode

pub const fn osc_div(&self) -> OscDiv

Oscillator Divide

pub const fn set_osc_div(&mut self, val: OscDiv)

Oscillator Divide

pub const fn unused4(&self) -> bool

This bit is unused. Always reads zero.

pub const fn set_unused4(&mut self, val: bool)

This bit is unused. Always reads zero.

pub const fn unused5(&self) -> bool

This bit is unused. Always reads zero.

pub const fn set_unused5(&mut self, val: bool)

This bit is unused. Always reads zero.

pub const fn rst_def(&self) -> bool

Reset Defaults

pub const fn set_rst_def(&mut self, val: bool)

Reset Defaults

pub const fn for_sclk(&self) -> bool

Force System Clock

pub const fn set_for_sclk(&mut self, val: bool)

Force System Clock

pub const fn fct_fail(&self) -> bool

Read only: Frequency Count Fail

pub const fn set_fct_fail(&mut self, val: bool)

Read only: Frequency Count Fail

pub const fn fct_val(&self) -> bool

Read only: Frequency Count Valid. Indicates that a valid frequency count may be read from FRQCNT.

pub const fn set_fct_val(&mut self, val: bool)

Read only: Frequency Count Valid. Indicates that a valid frequency count may be read from FRQCNT.

pub const fn ent_val(&self) -> bool

Read only: Entropy Valid

pub const fn set_ent_val(&mut self, val: bool)

Read only: Entropy Valid

pub const fn tst_out(&self) -> bool

Read only: Test point inside ring oscillator.

pub const fn set_tst_out(&mut self, val: bool)

Read only: Test point inside ring oscillator.

pub const fn err(&self) -> bool

Read: Error status

pub const fn set_err(&mut self, val: bool)

Read: Error status

pub const fn tstop_ok(&self) -> bool

TRNG_OK_TO_STOP

pub const fn set_tstop_ok(&mut self, val: bool)

TRNG_OK_TO_STOP

pub const fn lrun_cont(&self) -> bool

Long run count continues between entropy generations

pub const fn set_lrun_cont(&mut self, val: bool)

Long run count continues between entropy generations

pub const fn prgm(&self) -> bool

Programming Mode Select

pub const fn set_prgm(&mut self, val: bool)

Programming Mode Select